==> eiffelstudio-16.05.tar: F_code/C1/ch4.h <==

#ifndef _C1_ch4_
#define _C1_ch4_

#ifdef __cplusplus
extern "C" {
#endif

extern void F4_43(EIF_REFERENCE);
extern EIF_CHARACTER_32 F4_56(EIF_REFERENCE, EIF_CHARACTER_32);
RTOSHF (EIF_REFERENCE,68)
static EIF_REFERENCE F4_68_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_68(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,69)
static EIF_REFERENCE F4_69_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_69(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,70)
static EIF_REFERENCE F4_70_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_70(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,71)
static EIF_REFERENCE F4_71_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_71(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,72)
static EIF_REFERENCE F4_72_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_72(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,73)
static EIF_REFERENCE F4_73_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_73(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,74)
static EIF_REFERENCE F4_74_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_74(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,75)
static EIF_REFERENCE F4_75_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_75(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,76)
static EIF_REFERENCE F4_76_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_76(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,77)
static EIF_REFERENCE F4_77_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_77(EIF_REFERENCE);
extern void EIF_Minit4(void);
extern EIF_REFERENCE F471_2203(EIF_REFERENCE);
extern EIF_REFERENCE F469_2203(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif

==> eiffelstudio-18.01.10.1424.tar: F_code/C1/ch4.h <==

#ifndef _C1_ch4_
#define _C1_ch4_

#ifdef __cplusplus
extern "C" {
#endif

extern void F4_43(EIF_REFERENCE);
extern EIF_CHARACTER_32 F4_56(EIF_REFERENCE, EIF_CHARACTER_32);
RTOSHF (EIF_REFERENCE,68)
static EIF_REFERENCE F4_68_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_68(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,69)
static EIF_REFERENCE F4_69_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_69(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,70)
static EIF_REFERENCE F4_70_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_70(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,71)
static EIF_REFERENCE F4_71_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_71(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,72)
static EIF_REFERENCE F4_72_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_72(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,73)
static EIF_REFERENCE F4_73_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_73(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,74)
static EIF_REFERENCE F4_74_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_74(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,75)
static EIF_REFERENCE F4_75_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_75(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,76)
static EIF_REFERENCE F4_76_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_76(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,77)
static EIF_REFERENCE F4_77_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_77(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,78)
static EIF_REFERENCE F4_78_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_78(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,79)
static EIF_REFERENCE F4_79_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_79(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,80)
static EIF_REFERENCE F4_80_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_80(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,81)
static EIF_REFERENCE F4_81_body(EIF_REFERENCE);
extern EIF_REFERENCE F4_81(EIF_REFERENCE);
extern void EIF_Minit4(void);
extern EIF_REFERENCE F520_2436(EIF_REFERENCE);
extern EIF_REFERENCE F518_2436(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
